% run a single tomography inversion with some data and regularization options
clear
close all

%% parameters for tinkering
data_type = 1; % 1=teleseismic EQ, 2=local EQ, 3=both
damping_scalar   = 10;
smoothing_scalar = 10;

%% load inversion ingredients
if data_type==1
    load SubZone_BWtomo_tele_ingredients.mat
elseif data_type==2
    load SubZone_BWtomo_local_ingredients.mat
elseif data_type==3
    load SubZone_BWtomo_teleANDlocal_ingredients.mat
end

% residual time histogram
figure(2), clf, hold on
hist(d_obs,20)
xlabel('Residual time [s]')
h=findobj(gca,'Type','patch');
h.FaceColor = 'k';

%% tomography inversion
GR = [ G; damping_scalar*eye(length(mz)); smoothing_scalar*LR ];
dR = [ d_obs; zeros(length(mz),1); zeros(length(mz),1) ];

mdv = lsqr(GR,dR,1e-3,25);
misfit = d_obs-G*mdv;
variance_reduction = 100*(var(d_obs) - var(misfit))/var(d_obs)

%% plot tomography figure
m_mat = reshape(mdv,length(zg),length(yg));

wpos=[50 50 450 450]; 
figure(3), clf, set(gcf,'position',wpos), hold on
imagesc(yg,-zg,m_mat)
yy = 200:10:700;
scatter(yy, 0*yy,'k^')
if data_type>1
    scatter(all_eqy,-all_eqz,'w*')
end
colorbar
caxis([-0.03 0.03])
cmap=colormap(jet); colormap(flipud(cmap));
axis equal
axis tight
xlabel('Distance (km)')
ylabel('Depth (km)')
set(gca,'Layer','top')
set(gcf,'PaperPositionMode','auto');
print(['tomography_type' num2str(data_type) '_d' num2str(round(damping_scalar)) ...
    '_s' num2str(round(smoothing_scalar)) '.jpeg'],'-djpeg','-r300');

figure(2)
hist(misfit,20)